summaryrefslogtreecommitdiff
path: root/bin
diff options
context:
space:
mode:
Diffstat (limited to 'bin')
-rw-r--r--bin/bbstoreaccounts/bbstoreaccounts.cpp7
1 files changed, 6 insertions, 1 deletions
diff --git a/bin/bbstoreaccounts/bbstoreaccounts.cpp b/bin/bbstoreaccounts/bbstoreaccounts.cpp
index 829f1a01..3f911b92 100644
--- a/bin/bbstoreaccounts/bbstoreaccounts.cpp
+++ b/bin/bbstoreaccounts/bbstoreaccounts.cpp
@@ -358,7 +358,7 @@ int DeleteAccount(Configuration &rConfig, int32_t ID, bool AskForConfirmation)
return 1;
}
// Back to original user, but write is maintained
user.reset();
}
@@ -403,6 +403,11 @@ int DeleteAccount(Configuration &rConfig, int32_t ID, bool AskForConfirmation)
}
}
+#ifdef WIN32
+ // Cannot remove files while holding a lock on them
+ writeLock.ReleaseLock();
+#endif
+
int retcode = 0;
// Thirdly, delete the directories...
@@ -358,7 +358,7 @@ int DeleteAccount(Configuration &rConfig, int32_t ID, bool AskForConfirmation)
return 1;
}
- // Back to original user, but write is maintained
+ // Back to original user, but write lock is maintained
user.reset();
}